@@ -40,12 +40,13 @@ class ConfigReader(object):
   def parse(self):
     "Parse the whole file"
     while not self.reader.finished():
-      self.parseline(self.reader.currentnonblank())
+      self.parseline(self.reader.currentline())
       self.reader.nextline()
 
   def parseline(self, line):
     "Parse a single line"
-    line = line[:-1]
+    if line == '':
+      return
     if line.startswith('#'):
       return
     if line.startswith('['):
